@@ -1,40 +1,35 @@
+import os
 from argparse import ArgumentParser
 
-import numpy as np
-
-from elasticai.creator.vhdl.number_representations import (
-    FloatToSignedFixedPointConverter,
-)
-from elasticai.creator.vhdl.rom import Rom
+from elasticai.creator.vhdl.components.rom_component import RomComponent
+from elasticai.creator.vhdl.number_representations import float_values_to_fixed_point
 from elasticai.creator.vhdl.vhdl_formatter.vhdl_formatter import format_vhdl
 
 
 def main():
     arg_parser = ArgumentParser()
     arg_parser.add_argument(
-        "--file",
-        help="filepath of the generated vhd file",
+        "--path",
+        help="path to folder for generated vhd files",
         required=True,
     )
     args = arg_parser.parse_args()
-    file_path = args.file
-
+    if not os.path.isdir(args.path):
+        os.mkdir(args.path)
     rom_name = "bi_rom"
+    file_path = os.path.join(args.path, f"{rom_name}.vhd")
+
     data_width = 12
     frac_width = 4
     # biases for the input gate
-    Bi = np.array([1.1])
-
-    floats_to_signed_fixed_point_converter = FloatToSignedFixedPointConverter(
-        bits_used_for_fraction=frac_width, strict=False
-    )
-    array_value = [floats_to_signed_fixed_point_converter(x) for x in Bi]
+    bi = [1.1]
 
     with open(file_path, "w") as writer:
-        rom = Rom(
+        rom = RomComponent(
             rom_name=rom_name,
-            data_width=data_width,
-            values=array_value,
+            values=float_values_to_fixed_point(
+                bi, total_bits=data_width, frac_bits=frac_width
+            ),
             resource_option="auto",
         )
         for line in rom():
