@@ -4,7 +4,7 @@
 from typing import Any
 
 import torch
-from torch import Tensor, jit
+from torch import jit
 
 
 @jit.script
